%#eml
%For computing the steady state values. No acetaldehyde input 
function dStatesdt = bandpassODEExtended(t, States, P, AA)
   
    TetR = States(1);    
    CI = States(2);
    LacI = States(3);
    GFP = States(4);
    LuxI = States(5);
    AHLi = States(6); %intracellular AHL concentration
    AHLe = States(7); %extracellular AHL concentration
    R = States(8); %Complex between LuxR-AHL
    RFP = States(9); 

    dTetRdt = P.alphaTetR*(1 - ((AA / P.betaAcA)^P.n5)/(1 + (AA / P.betaAcA)^P.n5)) - ...  % Repression by AlcR_AA
              P.gammaTetR*TetR;                                            % Degradation  
    
    dCIdt = P.alphaC / (1 + (TetR / P.betaT)^P.n3) - ...                    % Repression by TetR
            P.gammaC*CI;                                                    % Degradation
       
    dLacIdt = P.alphaL1 / (1 + (CI / P.betaC)^P.n2) + ...                  % LacI: Repression by CI
              P.alphaL2 / (1 + (TetR / P.betaT)^P.n3) - ...                % LacI_M1: Repression by TetR 
              P.gammaL*LacI;                                               % Degradation
    
    dGFPdt = P.alphaG / (1 + (LacI / P.betaL)^P.n1) - ...                  % Repression by LacI / LacI_M1
             P.gammaG*GFP;                                                 % Degradation
    
    dLuxIdt = P.alphaLuxI / (1 + (CI / P.betaC)^P.n2) - ...                % Repression by CI
              P.gammaLuxI*LuxI;                                            % Degradation
          
    dAHLidt = P.ks1*LuxI - ...                                             % Production by LuxI
              P.ks0*AHLi - ...                                             % Degradation
              P.eta*(AHLi - AHLe);                                         % Diffusion (in and out)                                                                                                                                              
                                                                                                                                                                                                             
    dAHLedt = - P.kse*AHLe + ...                                           % Degradation
              P.etaExt*(AHLi - AHLe);                                      % Diffusion (in and out)  
     
    dRdt = P.rho*(P.LuxR)^2*(AHLi)^2 - ...                                 % Dimerization of LuxR-AHL
           P.gammaR*R;                                                     % Degradation of R
    
    dRFPdt = P.alphaRFP / (1 + (R / P.thetaR)^P.n4) - ...                  % Repression by R (the LuxR-AHL complex)
             P.gammaRFP*RFP;                                               % Degradation
    
                                         
                                                                                                                                                                                                        
                                                                           
    dStatesdt = [dTetRdt; dCIdt; dLacIdt; dGFPdt; dLuxIdt; dAHLidt; dAHLedt; dRdt; dRFPdt];
end