%#codegen
function Parameters = bandpassParameters(param)

    %% States in microMol
    % GFP: GFP concentration
    % LacI: LacI + LacI_M1 concentration
    % CI: cI concentration
    % LuxI : LuxI
    % AHLi : intracellular AHL concentration
    % AHLe : extracellular AHL concentration
    % R : complex between LuxR-AHL concentration
    % RFP = States(8);  %We need the ODE for this!
    % TetR = States(9);
    
   

    %% Inputs
    % A: Acetaldehyde concentration


    %% Parameter definition
    % Protein Synthesis Rates in microMol / min
    Parameters.alphaTetR = 1; %we need this
    Parameters.alphaC = param;
    Parameters.alphaL1 = 1;
    Parameters.alphaL2 = 1;
    Parameters.alphaG = 2;   
    Parameters.alphaLuxI = 1;  %Just an assumption
    Parameters.ks1 = 0.01; % We need this  % synthesis rate for intracellular AHL  Reference: same as for Parameters. ks0
    %LuxR/AHL dimerization in 1/((microMolar)^3 * min )
    Parameters.rho = 0.5;
    Parameters.alphaRFP = 1;   %We should check this ???
    

    % Repression Coefficients in microMolar
    Parameters.betaAcA = 7.124; % Repression coefficient for AlcA_AA complex ??? We need this
    Parameters.betaT = 0.1; % we need this ??  % Repression coefficient for TetR  Ref: same as for ks1
    Parameters.betaC = 0.008; %repression coefficient for CI
    Parameters.betaL = 0.8; % repression coefficient for LacI
    Parameters.thetaR = 0.01; % Paper: 0.01 (AHL / LuxR Binding)  %Should check this
    

    % Protein Decay in 1/min
    Parameters.gammaTetR = 0.0692; % we need this
    Parameters.gammaC = 0.0692;
    Parameters.gammaL = 0.0231;
    Parameters.gammaG = 0.0692;
    Parameters.gammaLuxI = 0.0167; % reference:http://www.sciencedirect.com/science/article/pii/S0303264705001267,   found in:  http://2010.igem.org/Team:MIT_tmodel
    Parameters.ks0 = 1;
    Parameters.kse = 1; 
    Parameters.gammaR = 0.0231; % We need this!
    Parameters.gammaRFP = 0.0041 ; % we consider that RFP has a much loger lifetime than the LVA tagged GFP

   

    % Transcription Factor Cooperativity (TODO: Check if & where we need this!)
    Parameters.n1 = 2;
    Parameters.n2 = 2;
    Parameters.n3 = 2; 
    Parameters.n4 = 1; 
    Parameters.n5 = 1.352; 
    
    % AHL Diffusion
    Parameters.eta = 2; % Check! Diffusion rate accross the cell membrane  Reference: same as for Parametes.ks0  .... but the values given in the paper are dimensionless
    Parameters.etaExt = 1; % Find this!
    
    %LuxR concentration is constant
    Parameters.LuxR = 0.5; 
    
    %The number of cells - in this case we consider only 1 cell
    Parameters.N = 1;
end
